# cookdir
initializing directories and files by recipe(template)

current function:
1. self-defined recipe(template) using yaml
2. create initial files

future plan:
1. a command showing all template, like cookdir list
2. a command print the content of specific template, like cookdir show template
3. template shortcut, since now i should type the full filename of a template
4. make this a package, so that i can pip install it rather than git pull it.
5. more freedom on template file, now i should put the template in basedir/recipe/ directory, 
   it will has a argument directly pointing to a template file anywhere.

wanting:
Anyone who has some useful recipe(template) can commit PR, and anyone has some function suggestion can commit PR or issues.
I appreciate all of you.
